#
# spec file for package libnvme
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1

%bcond_without check

Name:           libnvme
Version:        1.4+27.g5ae1c3
Release:        150500.4.6.1
Summary:        Linux-native nvme device management library
License:        LGPL-2.1-or-later
URL:            https://github.com/linux-nvme/libnvme/
Source0:        libnvme-%{version}.tar.gz
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libjson-c-devel
BuildRequires:  meson
BuildRequires:  libuuid-devel
BuildRequires:  openssl-devel
BuildRequires:  python3-devel
BuildRequires:  keyutils-devel
BuildRequires:  swig

%description
Provides library functions for accessing and managing NVMe devices on a Linux
system.

%package -n %{name}%{sover}
Summary:        Linux-native nvme device management library

%description -n %{name}%{sover}
Provides library functions for accessing and managing NVMe devices on a Linux
system.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{sover} = %{version}
Requires:       %{name}-mi%{sover} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        mi%{sover}
Summary:        NVMe Managament Interface library for %{name}

%description    mi%{sover}
Provides library functions for managing NVMe devices via the NVMe
Managament Interface.

%package -n     python3-libnvme
Summary:        Python binding for %{name}

%description -n python3-libnvme
Provides library functions for accessing and managing NVMe devices on a Linux
system.

Python binding part.

%prep
%autosetup -p1

%build
export KBUILD_BUILD_TIMESTAMP=@${SOURCE_DATE_EPOCH:-$(date +%s)}
%meson \
    -Ddocs=man \
    -Ddocs-build=true \
    -Dversion-tag=%{version}
%meson_build

%if %{with check}
%check
%meson_test
%endif

%install
%meson_install

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%post -n %{name}-mi%{sover} -p /sbin/ldconfig
%postun -n %{name}-mi%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc README.md
%{_libdir}/%{name}.so.%{sover}*

%files devel
%doc README.md
%{_includedir}/*
%{_libdir}/%{name}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-mi.pc
%{_mandir}/*/*.gz

%files -n %{name}-mi%{sover}
%license COPYING
%doc README.md
%{_libdir}/%{name}-mi.so.%{sover}*

%files -n python3-libnvme
%dir %{python3_sitearch}/libnvme
%{python3_sitearch}/libnvme/*.so
%{python3_sitearch}/libnvme/__init__.py
%{python3_sitearch}/libnvme/nvme.py

%changelog
* Thu Jul 27 2023 dwagner@suse.de
- Update to version 1.4+27.g5ae1c3:
  * tree: Add getter for subsystem iopolicy (bsc#1124564)
  * nvme-tree: avoid warning in 'list-subsys' (bsc#bsc#1212598)
  * tree: Scan all subsystems (bsc#bsc#1212598)
  * tree: Don't open nvme devices until it's absolutely required
    (bsc#1213527 bsc#1213686)
  * tree: Use nvme_ipaddrs_eq() to compare IP addresses
  * util: rename ipaddrs_eq() to nvme_ipaddrs_eq() and make public.
  * util: Add ipaddrs_eq() to check whether two IP addresses are equal
  * fabrics: check genctr after getting discovery entries (bsc#1213618)
  * ioctl: fix RAE bit on last Get Log Page command (bsc#1213618)
* Thu May 25 2023 daniel.wagner@suse.com
- Update to version v1.4 (jsc#PED-553 jsc#PED-3884)
  - Fix invalid string lenght calculcation for UUID (bsc#1209906)
  * fabrics: Fix bad UUID size introduced in recent UUID changes
  - Fix segmentation fault during garbage collection (bsc#1209905)
  * python: Fix segmentation fault during garbage collection
  * Python: Fix crash during garbage collection
  - Always sanitize traddr and trsvcid entries (bsc#1207435)
  * fabrics: Always sanitize discovery log entries
  * util: Add ECONNECTREFUSED to enum nvme_connect_err
  - Allow tracking unique discover controllers (bsc#1186689)
  * tree: Add unique discovery controller flag
  - Enabled unit test on s390x again (bsc#1207687, bsc#1207686)
  * test: mi: Explicitly zero args for test API invocations
- Replaced old nbft implementation with the upstream one
- Applied nbft symbol patch directly
  * remove 0001-libnvme-use-LIBNVME_1_2_1-version-for-nbft-commands.patch
- Don't enable TLS if kernel does not support it (git-fixes)
  * fabrics: Do not pass unsupported options to kernel
- Set version-tag so that version are correctly reported
* Mon Jan 30 2023 mwilck@suse.com
- temporarily disable unit tests on s390x (bsc#1207687, bsc#1207686)
* Tue Jan 24 2023 mwilck@suse.com
- Use symbol version LIBNVME_1_2_1 for nbft support options
  * 0001-libnvme-use-LIBNVME_1_2_1-version-for-nbft-commands.patch
  * added %%test section in spec file to run unit tests
* Fri Jan 20 2023 mwilck@suse.com
- Update to version 1.2+1.g41e1016:
  * Add support for booting from NVMe-oF/TCP according to NVM Express
  Boot Specification v1.0 (jsc#PED-1449)
  * Add support for "nvme show-nbft" and "nvme connect-nbft" subcommands
* Wed Nov  2 2022 daniel.wagner@suse.com
- Update to version 1.2 (jsc#PED-553):
  * 64-bit Reference Tags and TP-4068 changes
  * Add more details for return code of MI admin cmds
  * Fix poll.h includes
  * Parse dhchap_host_key on controller level
  * Regenerate all documentation
  * Update json config schema for missing dhchap host key
  * build: Add support to build against LibreSSL
  * build: Drop -nostdinc for LibreSSL header checks
  * fabrics: Add new TP8010 definitions
  * fabrics: Add nvmf_get_discovery_wargs()
  * fabrics: Duplicate strings when merging configs
  * fabrics: Filter out empty strings in add_argument()
  * fabrics: Fix build_options() return values
  * fabrics: Use fallthrough statement
  * fabrics: sanitize dump-config output
  * ioctl: Honor rae in nvme_get_nsid_log
  * ioctl: Set log page offset for nvme_get_log_telemetry_host
  * json-schema: add dhchap_key details to host section
  * json: Enforce correctly formatted JSON config files
  * json: Verify JSON config file starts with an array
  * json: fixup dhchap_ctrl_key definitions
  * libnvme-mi: Introduce NVMe Managament Interface library
  * mi-mctp: Add timeout support to MCTP transport
  * mi: Add Get Log Page helpers
  * mi: Add Identify function for secondary controller list
  * mi: Add Identify helper for ns-descs and primary-ctrl-caps
  * mi: Add endpoint get/set timeout API
  * mi: Add firmware download and commit commands
  * mi: Add identify helper for nsid-capable Controller List
  * mi: Add identify helpers for namespace lists
  * mi: Add identify helpers for namespaces
  * mi: Add maximum More Processing Required limit API
  * mi: Allow Admin-message sized More Processing Required responses
  * mi: Distinguish MI status from NVMe (CDW3) status
  * mi: Fix C++ compiler errors
  * mi: Implement Format NVM command
  * mi: Implement Get & Set Features Admin commands
  * mi: Implement NS attach command and helpers
  * mi: Implement Namespace Management command and create/delete helpers
  * mi: Implement Sanitize command
  * mi: Init ctrl_id within xfer
  * mi: Introduce a helper for response status, unify values with ioctls
  * mi: Set log page offset for nvme_get_log_telemetry_host
  * mi: add nvme_mi_status_to_string()
  * mi: fix a memory leak in nvme_mi_open_mctp()
  * mi: fix get_log_page chunked offset check
  * mi: unify MI Get Log Page function with ioctl API
  * nvme-tree: avoid segfault if auth keys are unavailable
  * python: Use nvmf_get_discovery_wargs()
  * python: add missing ctrl attrs to Python bindings
  * rpmbuild: Enable 'make rpm' to build rpm pkgs #408
  * tree: rename controller 'dhchap_key' to 'dhchap_ctrl_key'
  * types: Move enum nvme_data_tfr to types
  * update/cleanup of documentation
  * util: Add LINE_MAX define
  * util: Add get feature length 2 API to support direction parameter
  * util: Add simple UUID type
  * util: Do not expose fallthrough defines
  * various build fixes
  * various fixes reported by coverity
- Drop upstream patches
  * remove 0001-fabrics-Lower-log-level-in-__nvmf_add_ctrl.patch
  * remove 0002-fabrics-Remove-double-connection-error-logging.patch
  * remove 0003-fabrics-Introduce-connection-connect-error-mapping.patch
  * remove 0004-libnvme-Export-nvme_ctrl_get_config.patch
  * remove 0005-tree-Factor-lookup-code-for-controller.patch
  * remove 0006-fabrics-Consider-config-from-file-when-adding-new-co.patch
  * remove 0007-python-add-missing-ctrl-attrs-to-Python-bindings.patch
  * remove 0008-libnvme-accessors-for-dhchap_key-variables.patch
  * remove 0009-fabrics-Update-controller-authentication-in-nvmf_add.patch
  * remove 0010-json-fixup-dhchap_ctrl_key-definitions.patch
  * remove 0011-tree-rename-controller-dhchap_key-to-dhchap_ctrl_key.patch
  * remove 0012-Parse-dhchap_host_key-on-controller-level.patch
  * remove 0013-json-schema-add-dhchap_key-details-to-host-section.patch
  * remove 0014-nvme-tree-avoid-segfault-if-auth-keys-are-unavailabl.patch
  * remove 0015-fabrics-restructrure-nvmf_get_discovery_log.patch
  * remove 0016-tree-simplifiy-nvme_subsystem_lookup_namespace.patch
  * remove 0017-tree-make-nvme_subsystem_scan_namespace-idempotent.patch
  * remove 0018-tree-make-nvme_ctrl_scan_namespace-idempotent.patch
  * remove 0019-Fix-llx-lx-build-warnings-on-powerpc.patch
  * remove 0020-fabrics-sanitize-dump-config-output.patch
  * remove 0021-fabrics-Fix-build_options-return-values.patch
- Make man page build conditiional. Install man page location has been
  fixed upstream.
- Mark the Python directory own by the libnvme3-python package
- Use fixed manpage build date (boo#1047218)
- Fix installation of manual pages to make them accessible
* Wed Sep 21 2022 dwagner@suse.de
- Fixes for controller authentication (bsc#1201501 bsc#1201700 bsc#1201701 bsc#1201717)
  * add 0007-python-add-missing-ctrl-attrs-to-Python-bindings.patch
  * add 0008-libnvme-accessors-for-dhchap_key-variables.patch
  * add 0009-fabrics-Update-controller-authentication-in-nvmf_add.patch
  * add 0010-json-fixup-dhchap_ctrl_key-definitions.patch
  * add 0011-tree-rename-controller-dhchap_key-to-dhchap_ctrl_key.patch
  * add 0012-Parse-dhchap_host_key-on-controller-level.patch
  * add 0013-json-schema-add-dhchap_key-details-to-host-section.patch
  * add 0014-nvme-tree-avoid-segfault-if-auth-keys-are-unavailabl.patch
  * add 0015-fabrics-restructrure-nvmf_get_discovery_log.patch
- Subsystem scanning logic fixes
  * add 0016-tree-simplifiy-nvme_subsystem_lookup_namespace.patch
  * add 0017-tree-make-nvme_subsystem_scan_namespace-idempotent.patch
  * add 0018-tree-make-nvme_ctrl_scan_namespace-idempotent.patch
- Fix PowerPC build warnings
  * add 0019-Fix-llx-lx-build-warnings-on-powerpc.patch
- Fabrics fixes
  * add 0020-fabrics-sanitize-dump-config-output.patch
  * add 0021-fabrics-Fix-build_options-return-values.patch
* Fri Jun  3 2022 dwagner@suse.de
- Reduce log noise and export error codes (bsc#1199994 bsc#1199503)
  * add 0001-fabrics-Lower-log-level-in-__nvmf_add_ctrl.patch
  * add 0002-fabrics-Remove-double-connection-error-logging.patch
  * add 0003-fabrics-Introduce-connection-connect-error-mapping.patch
- Apply configuration from JSON file (bsc#1199503)
  * add 0004-libnvme-Export-nvme_ctrl_get_config.patch
  * add 0005-tree-Factor-lookup-code-for-controller.patch
  * add 0006-fabrics-Consider-config-from-file-when-adding-new-co.patch
* Fri Apr  8 2022 daniel.wagner@suse.com
- Update to version 1.0:
  * tree: Remove default port setting for TCP and RDMA ports
  * tree: add 'f_args' argument to pass user data to the filter function
  * tree: remove 'ctrl_get_ana_state()'
  * tree: add namespace path iterators
  * tree: filter out namespaces
  * tree: update nvme_scan_filter_t usage
* Fri Apr  1 2022 daniel.wagner@suse.com
- Update to version 1.0-rc8:
  * types: Add support for get log - MI Command Supported
  * types: Add new Identify constant
  * types: Update persistent event entry struct added new fields
  * types: Add Host Initiated Data Gen Number to telemetry log struct
  * tree: always allocate config file in nvme_read_config()
  * tree: rework nvme_scan_subsystem()
  * tree: make subsystem name mandatory in nvme_scan_ctrl()
  * tree: move nvme_init_subsystem() into nvme_lookup_subsystem()
  * tree: do not return error when filtering out subsystems
  * tree: add debugging messages during scanning
  * tree: Handle NULL subsysname in nvme_scan_ctrl()
  * tree: Fix subsystem initialization in nvme_scan_ctrl()
  * tree: Fix leaking 'name' in nvme_subsystem_lookup_namespace()
  * tree: Avoid dereferencing nvme_subsystem_t before its check for NULL
  * tree: Clarify NULL return values from nvme_get_attr()
  * fabrics: Invoke nvmf_dim() with provided tas argument
  * fabrics: add 'nvmf_update_config()'
  * fabrics: Avoid out of bounds string chomping
  * fabrics: Free old traddr in nvmf_add_ctrl
  * fabrics: update log level for write failures
  * fabrics: Streamlining documentation
  * fabrics: Fix leaking ctrl in nvmf_connect_disc_entry()
  * fabrics: Add missing break in a switch
  * ioctl: Remove attribute packed and alignedof for args structs
  * ioctl: Align arguments indentation with braces
  * json: fix endless loop scanning for controllers
  * Remove nvme_init_id_ns
  * Add lbstm support for create-ns
  * documentation updates
* Fri Mar 18 2022 daniel.wagner@suse.com
- Update to version 1.0-rc7:
  * linux: fixup log page offset in nvme_get_log_page()
  * tree: Add support for default trsvcid for all controllers (bsc#1195858)
  * tree: fixup coredump during nvme discover
* Fri Mar 11 2022 daniel.wagner@suse.com
- Update to version 1.0-rc6:
  * tree: add nvme_ctrl_get_ana_state() (bsc#1195938)
  * tree: link paths to namespaces in nvme_subsystem_scan_namespace() (bsc#1195938)
  * ioctl.h: ns list bug fix (wrong cns value)
  * types.h: Key Value Command Set Identifier added (NVME_CSI_KV)
  * types: fix status code type bug (wrong masking)
* Tue Mar  8 2022 daniel.wagner@suse.com
- Update License information. The library is released under
  LGPL-2.1-or-later and not LGPL-2.1-only.
* Thu Mar  3 2022 daniel.wagner@suse.com
- Update to version 1.0-rc5:
  * ioctl: Set lsp to action in nvme_get_log_persistent_event (bsc#1196121)
  * tree: Ignore traddr case in nvme_lookup_ctrl() (bsc#1194025)
  * fabrics: Do not swap bytes for system uuid (bsc#1196565)
  * documentation updates
* Tue Feb 22 2022 daniel.wagner@suse.com
- Update to version 1.0-rc4:
  * fabrics: add default port number for NVMe/TCP I/O controllers
  * linux: Update size when telemetry controller initiated data is unavailable
  * add cdw13 for set_feature_args structure
  * Add support for TP8010
  * Documentation cleanups
* Fri Feb 11 2022 daniel.wagner@suse.com
- Update to version v1.0-rc3:
  * Properly create manuals/documentation
  * Fix memleaks in __nvme_free_ns() and nvme_scan_subsystem()
  * nvme: get log domain id included in Log Specific Identifier
  * nvme: Add nulbaf(Number of Unique Capability LBA Formats) field on nvmd_id_ns
  * ioctl: Add identify ioctl for CNS 09h, 0Ah
  * nvme: Add Enhanced Controller Meta Data(FID: 0x7D)
  * nvme: Add Supported Capacity Configuration List log page(LID: 0x11)
  * tree: do not set dhchap_key to 'none'
  * tree: restart controller lookup
  * tree: fixup memory leak in nvme_scan_ctrl()
  * Rename nvme_path_get_subsystem()
  * Remove nvme_reset_topology()
- Use precompiled documentation instead regenerating it
* Tue Feb  1 2022 daniel.wagner@suse.com
- Update to version 1.0~2:
  * Add fabrics config option 'tls'
  * Logging infrastructure reworked (API break)
  * Changed argument structs layout (API break)
  * Changed scan API (API break)
  * Fixed ctrl_loss_tmo handling concerning values of '-1'
  * Various build fixes
* Wed Jan 19 2022 daniel.wagner@suse.com
- Remove Provide for python package.
- Remove explicit tar file name for setup step.
* Tue Jan 18 2022 daniel.wagner@suse.com
- Use osc_scm to manage upstream input source.
* Tue Jan 18 2022 daniel.wagner@suse.com
- Fix Source URL
* Fri Jan 14 2022 daniel.wagner@suse.com
- Initial package creation for libnvme
